import { httpApp } from "@/plugins/axiosApp";
import { Question } from "@/types";

/** 清理仲裁任务(libraryId 与其他参数互斥填写) */
export async function clearArbitrateTask(
  libraryId?: string,
  subjectCode?: string,
  groupNumber?: string
) {
  const form = new FormData();
  libraryId && form.append("groupNumber", libraryId);
  subjectCode && form.append("subjectCode", subjectCode);
  groupNumber && form.append("groupNumber", groupNumber);
  return httpApp.post("/admin/exam/arbitrate/clear", form);
}

/** 查看单个学生的仲裁任务 */
export async function getSingleArbitrateTask(historyId: string) {
  const form = new FormData();
  historyId && form.append("historyId", historyId);
  return httpApp.post("/admin/exam/arbitrate/getTask", form);
}

/** 查看仲裁任务2次分数 */
export async function getArbitrateList(historyId: string) {
  const form = new FormData();
  historyId && form.append("historyId", historyId);
  return httpApp.post("/admin/exam/arbitrate/getArbitrationList", form);
}

/** 批量仲裁得到单个学生的仲裁任务 */
export async function getOneOfArbitrateTask(
  subjectCode: string,
  groupNumber: string
) {
  const form = new FormData();
  form.append("subjectCode", subjectCode);
  form.append("groupNumber", groupNumber);
  return httpApp.post("/admin/exam/arbitrate/getTask", form);
}

/** 批量仲裁得到任务总数 */
export async function getArbitrateTaskStatus(
  subjectCode: string,
  groupNumber: string
) {
  const form = new FormData();
  form.append("subjectCode", subjectCode);
  form.append("groupNumber", groupNumber);
  return httpApp.post("/admin/exam/arbitrate/getStatus", form);
}

/** 批量仲裁设置 */
export async function getArbitrateSetting(
  historyId: string,
  subjectCode?: string,
  groupNumber?: string
) {
  const form = new FormData();
  historyId && form.append("historyId", historyId);
  subjectCode && form.append("subjectCode", subjectCode);
  groupNumber && form.append("groupNumber", groupNumber);
  return httpApp.post("/admin/exam/arbitrate/getSetting", form);
}

/** 批量仲裁历史 */
export async function getArbitrateHistory({
  subjectCode,
  groupNumber,
  pageNumber = 1,
  pageSize = 10,
  order = "markerTime",
  sort = "DESC",
}: {
  subjectCode: string;
  groupNumber?: string;
  pageNumber?: number; // 从1开始
  pageSize?: number;
  order?: "markerTime" | "markerScore";
  sort?: "ASC" | "DESC";
}) {
  const form = new FormData();
  form.append("subjectCode", subjectCode);
  groupNumber && form.append("groupNumber", groupNumber);
  form.append("pageNumber", pageNumber + "");
  form.append("pageSize", pageSize + "");
  form.append("order", order);
  form.append("sort", sort);
  return httpApp.post("/admin/exam/arbitrate/getHistory", form);
}

/** 保存仲裁任务 */
export async function saveArbitrateTask(
  libraryId: string,
  studentId: string,
  markerScore: number,
  scoreList: Array<number>
) {
  return httpApp.post("/admin/exam/arbitrate/saveTask", {
    libraryId,
    studentId,
    markerScore,
    scoreList,
  });
}
